__all__ = [
    'RuleConditionKey',
    'RuleCondition',
    'ComparableRuleCondition',
    'IdentityRuleCondition',
    'AcceptedAssignmentsCount',
    'AcceptedAssignmentsRate',
    'AssessmentEvent',
    'AssignmentsAcceptedCount',
    'CorrectAnswersRate',
    'FailRate',
    'FastSubmittedCount',
    'GoldenSetAnswersCount',
    'GoldenSetCorrectAnswersRate',
    'GoldenSetIncorrectAnswersRate',
    'IncomeSumForLast24Hours',
    'IncorrectAnswersRate',
    'NextAssignmentAvailable',
    'PendingAssignmentsCount',
    'PoolAccessRevokedReason',
    'RejectedAssignmentsCount',
    'RejectedAssignmentsRate',
    'SkillId',
    'SkippedInRowCount',
    'StoredResultsCount',
    'SubmittedAssignmentsCount',
    'SuccessRate',
    'TotalAnswersCount',
    'TotalAssignmentsCount',
    'TotalSubmittedCount',
]
import toloka.client.primitives.base
import toloka.client.primitives.operators
import toloka.util._extendable_enum
import typing


class RuleConditionKey(toloka.util._extendable_enum.ExtendableStrEnum):
    """An enumeration.
    """

    ACCEPTED_ASSIGNMENTS_COUNT = 'accepted_assignments_count'
    ACCEPTED_ASSIGNMENTS_RATE = 'accepted_assignments_rate'
    ASSESSMENT_EVENT = 'assessment_event'
    ASSIGNMENTS_ACCEPTED_COUNT = 'assignments_accepted_count'
    CORRECT_ANSWERS_RATE = 'correct_answers_rate'
    FAIL_RATE = 'fail_rate'
    FAST_SUBMITTED_COUNT = 'fast_submitted_count'
    GOLDEN_SET_ANSWERS_COUNT = 'golden_set_answers_count'
    GOLDEN_SET_CORRECT_ANSWERS_RATE = 'golden_set_correct_answers_rate'
    GOLDEN_SET_INCORRECT_ANSWERS_RATE = 'golden_set_incorrect_answers_rate'
    INCOME_SUM_FOR_LAST_24_HOURS = 'income_sum_for_last_24_hours'
    INCORRECT_ANSWERS_RATE = 'incorrect_answers_rate'
    NEXT_ASSIGNMENT_AVAILABLE = 'next_assignment_available'
    PENDING_ASSIGNMENTS_COUNT = 'pending_assignments_count'
    POOL_ACCESS_REVOKED_REASON = 'pool_access_revoked_reason'
    REJECTED_ASSIGNMENTS_COUNT = 'rejected_assignments_count'
    REJECTED_ASSIGNMENTS_RATE = 'rejected_assignments_rate'
    SKILL_ID = 'skill_id'
    SKIPPED_IN_ROW_COUNT = 'skipped_in_row_count'
    STORED_RESULTS_COUNT = 'stored_results_count'
    SUBMITTED_ASSIGNMENTS_COUNT = 'submitted_assignments_count'
    SUCCESS_RATE = 'success_rate'
    TOTAL_ANSWERS_COUNT = 'total_answers_count'
    TOTAL_ASSIGNMENTS_COUNT = 'total_assignments_count'
    TOTAL_SUBMITTED_COUNT = 'total_submitted_count'


class RuleCondition(toloka.client.primitives.base.BaseTolokaObject):
    def __init__(
        self,
        *,
        operator: typing.Optional[typing.Any] = None,
        value: typing.Optional[typing.Any] = None
    ) -> None:
        """Method generated by attrs for class RuleCondition.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    operator: typing.Optional[typing.Any]
    value: typing.Optional[typing.Any]


class ComparableRuleCondition(RuleCondition, toloka.client.primitives.operators.ComparableConditionMixin):
    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        *,
        value: typing.Optional[typing.Any] = None
    ) -> None:
        """Method generated by attrs for class ComparableRuleCondition.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[typing.Any]


class IdentityRuleCondition(RuleCondition, toloka.client.primitives.operators.IdentityConditionMixin):
    def __init__(
        self,
        operator: toloka.client.primitives.operators.IdentityOperator,
        *,
        value: typing.Optional[typing.Any] = None
    ) -> None:
        """Method generated by attrs for class IdentityRuleCondition.
        """
        ...

    operator: toloka.client.primitives.operators.IdentityOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[typing.Any]


class AcceptedAssignmentsCount(ComparableRuleCondition):
    """The number of accepted assignments of a task suite.

    `AcceptedAssignmentsCount` is used with collectors:
    - [AssignmentsAssessment](toloka.client.collectors.AssignmentsAssessment.md)

    See also:
    - AssignmentsAcceptedCount(toloka.client.conditions.AssignmentsAcceptedCount.md) — The number of assignments accepted from a Toloker.
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class AcceptedAssignmentsCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class AcceptedAssignmentsRate(ComparableRuleCondition):
    """The percentage of accepted assignments out of all checked assignments from a Toloker.

    `AcceptedAssignmentsRate` is used with collectors:
    - [AcceptanceRate](toloka.client.collectors.AcceptanceRate.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class AcceptedAssignmentsRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class AssessmentEvent(IdentityRuleCondition):
    """An assignment status change event.

    Possible values:
        * `ACCEPT` — An assignment was accepted.
        * `ACCEPT_AFTER_REJECT` — An assignment with the previously set `REJECTED` status was accepted.
        * `REJECT` — An assignment was rejected.

    `AssessmentEvent` condition can be used with the `==` operator only.

    `AssessmentEvent` is used with collectors:
    - [AssignmentsAssessment](toloka.client.collectors.AssignmentsAssessment.md).

    Example:
        The example shows how to automatically increase the overlap of a task suite when an assignment was rejected.

        >>> new_pool = toloka.pool.Pool(....)
        >>> new_pool.quality_control.add_action(
        >>>     collector=toloka.collectors.AssignmentsAssessment(),
        >>>     conditions=[toloka.conditions.AssessmentEvent == toloka.conditions.AssessmentEvent.REJECT],
        >>>     action=toloka.actions.ChangeOverlap(delta=1, open_pool=True),
        >>> )
        ...
    """

    class Type(toloka.util._extendable_enum.ExtendableStrEnum):
        """An enumeration.
        """

        ACCEPT = 'ACCEPT'
        ACCEPT_AFTER_REJECT = 'ACCEPT_AFTER_REJECT'
        REJECT = 'REJECT'

    def __init__(
        self,
        operator: toloka.client.primitives.operators.IdentityOperator,
        value: typing.Union[Type, str, None] = None
    ) -> None:
        """Method generated by attrs for class AssessmentEvent.
        """
        ...

    operator: toloka.client.primitives.operators.IdentityOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[Type]


class AssignmentsAcceptedCount(ComparableRuleCondition):
    """The number of assignments accepted from a Toloker.

    `AssignmentsAcceptedCount` is used with collectors:
    - [AnswerCount](toloka.client.collectors.AnswerCount.md)

    See also:
    - AcceptedAssignmentsCount(toloka.client.conditions.AcceptedAssignmentsCount.md) — The number of accepted assignments of a task suite.
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class AssignmentsAcceptedCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class CorrectAnswersRate(ComparableRuleCondition):
    """The percentage of correct responses.

    `CorrectAnswersRate` is used with collectors:
    - [GoldenSet](toloka.client.collectors.GoldenSet.md)
    - [MajorityVote](toloka.client.collectors.MajorityVote.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class CorrectAnswersRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class FailRate(ComparableRuleCondition):
    """Deprecated. The percentage of unsolved captchas.

    `FailRate` is used with collectors:
    - [Captcha](toloka.client.collectors.Captcha.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class FailRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class FastSubmittedCount(ComparableRuleCondition):
    """The number of assignments completed by a Toloker too fast.

    `FastSubmittedCount` is used with collectors:
    - [AssignmentSubmitTime](toloka.client.collectors.AssignmentSubmitTime.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class FastSubmittedCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class GoldenSetAnswersCount(ComparableRuleCondition):
    """The number of completed control tasks.

    `GoldenSetAnswersCount` is used with collectors:
    - [GoldenSet](toloka.client.collectors.GoldenSet.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class GoldenSetAnswersCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class GoldenSetCorrectAnswersRate(ComparableRuleCondition):
    """The percentage of correct responses to control tasks.

    `GoldenSetCorrectAnswersRate` is used with collectors:
    - [GoldenSet](toloka.client.collectors.GoldenSet.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class GoldenSetCorrectAnswersRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class GoldenSetIncorrectAnswersRate(ComparableRuleCondition):
    """The percentage of incorrect responses to control tasks.

    `GoldenSetIncorrectAnswersRate` is used with collectors:
    - [GoldenSet](toloka.client.collectors.GoldenSet.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class GoldenSetIncorrectAnswersRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class IncomeSumForLast24Hours(ComparableRuleCondition):
    """The Toloker's earnings for completed tasks in the pool during the last 24 hours.

    `IncomeSumForLast24Hours` is used with collectors:
    - [Income](toloka.client.collectors.Income.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class IncomeSumForLast24Hours.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class IncorrectAnswersRate(ComparableRuleCondition):
    """The percentage of incorrect responses.

    `IncorrectAnswersRate` is used with collectors:
    - [MajorityVote](toloka.client.collectors.MajorityVote.md)
    - [GoldenSet](toloka.client.collectors.GoldenSet.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class IncorrectAnswersRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class NextAssignmentAvailable(ComparableRuleCondition):
    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class NextAssignmentAvailable.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[bool]


class PendingAssignmentsCount(ComparableRuleCondition):
    """The number of pending assignments that must be checked.

    `PendingAssignmentsCount` is used with collectors:
    - [AssignmentsAssessment](toloka.client.collectors.AssignmentsAssessment.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class PendingAssignmentsCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class PoolAccessRevokedReason(IdentityRuleCondition):
    """The reason why a Toloker has lost access to a pool.

    Possible values:
        * `SKILL_CHANGE` — The Toloker no longer meets one or more filters.
        * `RESTRICTION` — The Toloker's access to tasks is blocked by a quality control rule.

    `PoolAccessRevokedReason` is used with collectors:
    - [UsersAssessment](toloka.client.collectors.UsersAssessment.md)
    """

    class Type(toloka.util._extendable_enum.ExtendableStrEnum):
        """An enumeration.
        """

        SKILL_CHANGE = 'SKILL_CHANGE'
        RESTRICTION = 'RESTRICTION'

    def __init__(
        self,
        operator: toloka.client.primitives.operators.IdentityOperator,
        value: typing.Union[Type, str, None] = None
    ) -> None:
        """Method generated by attrs for class PoolAccessRevokedReason.
        """
        ...

    operator: toloka.client.primitives.operators.IdentityOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[Type]


class RejectedAssignmentsCount(ComparableRuleCondition):
    """The number of rejected assignments of a task suite.

    `RejectedAssignmentsCount` is used with collectors:
    - [AssignmentsAssessment](toloka.client.collectors.AssignmentsAssessment.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class RejectedAssignmentsCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class RejectedAssignmentsRate(ComparableRuleCondition):
    """A percentage of rejected assignments submitted by a Toloker.

    `RejectedAssignmentsRate` is used with collectors:
    - [AcceptanceRate](toloka.client.collectors.AcceptanceRate.md)

    See also:
    - [RejectedAssignmentsCount](toloka.client.conditions.RejectedAssignmentsCount.md) — The number of rejected assignments of a task suite.
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class RejectedAssignmentsRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class SkillId(IdentityRuleCondition):
    """The ID of a changed skill which caused access blocking.

    `SkillId` provides details if the [PoolAccessRevokedReason](toloka.client.conditions.PoolAccessRevokedReason.md) condition equals `SKILL_CHANGE`.

    `SkillId` is used with collectors:
    - [UsersAssessment](toloka.client.collectors.UsersAssessment.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.IdentityOperator,
        value: typing.Optional[str] = None
    ) -> None:
        """Method generated by attrs for class SkillId.
        """
        ...

    operator: toloka.client.primitives.operators.IdentityOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[str]


class SkippedInRowCount(ComparableRuleCondition):
    """The number of tasks skipped in a row by a Toloker.

    `SkippedInRowCount` is used with collectors:
    - [SkippedInRowAssignments](toloka.client.collectors.SkippedInRowAssignments.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class SkippedInRowCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class StoredResultsCount(ComparableRuleCondition):
    """Deprecated. The number of times a Toloker entered captcha.

    `StoredResultsCount` is used with collectors:
    - [Captcha](toloka.client.collectors.Captcha.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class StoredResultsCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class SubmittedAssignmentsCount(ComparableRuleCondition):
    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class SubmittedAssignmentsCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class SuccessRate(ComparableRuleCondition):
    """Deprecated. A percentage of solved captchas out of all entered captchas.

    `SuccessRate` is used with collectors:
    - [Captcha](toloka.client.collectors.Captcha.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class SuccessRate.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[float]


class TotalAnswersCount(ComparableRuleCondition):
    """The number of completed tasks.

    `TotalAnswersCount` is used with collectors:
    - [GoldenSet](toloka.client.collectors.GoldenSet.md)
    - [MajorityVote](toloka.client.collectors.MajorityVote.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class TotalAnswersCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class TotalAssignmentsCount(ComparableRuleCondition):
    """The number of checked assignments out of all assignments submitted by a Toloker.

    `TotalAssignmentsCount` is used with collectors:
    - [AcceptanceRate](toloka.client.collectors.AcceptanceRate.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class TotalAssignmentsCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]


class TotalSubmittedCount(ComparableRuleCondition):
    """The number of assignments submitted by a Toloker.

    `TotalSubmittedCount` is used with collectors:
    - [AssignmentSubmitTime](toloka.client.collectors.AssignmentSubmitTime.md)
    """

    def __init__(
        self,
        operator: toloka.client.primitives.operators.CompareOperator,
        value: typing.Optional[int] = None
    ) -> None:
        """Method generated by attrs for class TotalSubmittedCount.
        """
        ...

    operator: toloka.client.primitives.operators.CompareOperator
    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    value: typing.Optional[int]
